==> gd32f1-0.4.0.crate: gd32f1-0.4.0/src/gd32f170/cec/tdata.rs <==
#[doc = "Register `TDATA` writer"]
pub struct W(crate::W<TDATA_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<TDATA_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<TDATA_SPEC>> for W {
    fn from(writer: crate::W<TDATA_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `TXDATA` writer - Tx Data register"]
pub struct TXDATA_W<'a> {
    w: &'a mut W,
}
impl<'a> TXDATA_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u8) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xff) | (value as u32 & 0xff);
        self.w
    }
}
impl W {
    #[doc = "Bits 0:7 - Tx Data register"]
    #[inline(always)]
    pub fn txdata(&mut self) -> TXDATA_W {
        TXDATA_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Transmit data register\n\nThis register you can [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [tdata](index.html) module"]
pub struct TDATA_SPEC;
impl crate::RegisterSpec for TDATA_SPEC {
    type Ux = u32;
}
#[doc = "`write(|w| ..)` method takes [tdata::W](W) writer structure"]
impl crate::Writable for TDATA_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets TDATA to value 0"]
impl crate::Resettable for TDATA_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> gd32f1-0.5.0.crate: gd32f1-0.5.0/src/gd32f170/cec/tdata.rs <==
#[doc = "Register `TDATA` writer"]
pub struct W(crate::W<TDATA_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<TDATA_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<TDATA_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<TDATA_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `TXDATA` writer - Tx Data register"]
pub struct TXDATA_W<'a> {
    w: &'a mut W,
}
impl<'a> TXDATA_W<'a> {
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub unsafe fn bits(self, value: u8) -> &'a mut W {
        self.w.bits = (self.w.bits & !0xff) | (value as u32 & 0xff);
        self.w
    }
}
impl W {
    #[doc = "Bits 0:7 - Tx Data register"]
    #[inline(always)]
    pub fn txdata(&mut self) -> TXDATA_W {
        TXDATA_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Transmit data register\n\nThis register you can [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [tdata](index.html) module"]
pub struct TDATA_SPEC;
impl crate::RegisterSpec for TDATA_SPEC {
    type Ux = u32;
}
#[doc = "`write(|w| ..)` method takes [tdata::W](W) writer structure"]
impl crate::Writable for TDATA_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets TDATA to value 0"]
impl crate::Resettable for TDATA_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
